@@ -10,6 +10,9 @@
 #include <memory>
 #include <functional>
 #include <array>
+#ifdef USE_MPI
+#include <boost/mpi.hpp>
+#endif
 #include <pybind11/pybind11.h>
 #include <pybind11/eigen.h>
 #include <pybind11/stl_bind.h>
@@ -368,11 +371,16 @@ public:
 
 class PyTransitionStepTreeDP: StOpt::TransitionStepTreeDP
 {
+
 public :
     PyTransitionStepTreeDP(const std::shared_ptr< StOpt::SpaceGrid >   &p_gridCurrent,  const std::shared_ptr< StOpt::SpaceGrid >   &p_gridPrevious, const  std::shared_ptr< StOpt::OptimizerDPTreeBase>   &p_optimizer):
         StOpt::TransitionStepTreeDP(std::dynamic_pointer_cast<StOpt::FullGrid>(p_gridCurrent),
                                     std::dynamic_pointer_cast<StOpt::FullGrid>(p_gridPrevious),
-                                    p_optimizer) {  }
+                                    p_optimizer
+#ifdef USE_MPI
+                                    , boost::mpi::communicator()
+#endif
+                                   ) {  }
 
     py::list  oneStepWrap(const std::vector< Eigen::ArrayXXd >  &p_phiIn,
                           const std::shared_ptr< StOpt::Tree>     &p_condExp) const
@@ -413,7 +421,11 @@ public :
     PySimulateStepTree(BinaryFileArchiveStOpt &p_ar,  const int &p_iStep,  const std::string &p_nameCont,
                        const   std::shared_ptr< StOpt::SpaceGrid > &p_pGridFollowing,
                        const  std::shared_ptr< StOpt::OptimizerDPTreeBase > &p_pOptimize):
-        StOpt::SimulateStepTree(p_ar, p_iStep, p_nameCont, p_pGridFollowing, p_pOptimize)
+        StOpt::SimulateStepTree(p_ar, p_iStep, p_nameCont, p_pGridFollowing, p_pOptimize
+#ifdef USE_MPI
+                                , boost::mpi::communicator()
+#endif
+                               )
     {}
 
     py::list  oneStepWrap(const py::list    &p_statevector,  const Eigen::ArrayXXd   &p_phiInOut) const
@@ -436,7 +448,11 @@ class PySimulateStepTreeControl : StOpt::SimulateStepTreeControl
 public :
     PySimulateStepTreeControl(BinaryFileArchiveStOpt &p_ar,  const int &p_iStep,  const std::string &p_nameCont,
                               const   std::shared_ptr< StOpt::SpaceGrid > &p_pGridFollowing, const  std::shared_ptr< StOpt::OptimizerDPTreeBase > &p_pOptimize):
-        StOpt::SimulateStepTreeControl(p_ar, p_iStep, p_nameCont, p_pGridFollowing, p_pOptimize)
+        StOpt::SimulateStepTreeControl(p_ar, p_iStep, p_nameCont, p_pGridFollowing, p_pOptimize
+#ifdef USE_MPI
+                                       , boost::mpi::communicator()
+#endif
+                                      )
     {}
 
     py::list  oneStepWrap(const py::list    &p_statevector,  const Eigen::ArrayXXd   &p_phiInOut) const
@@ -459,7 +475,11 @@ public :
     PyTransitionStepRegressionDP(const std::shared_ptr< StOpt::SpaceGrid >   &p_gridCurrent,  const std::shared_ptr< StOpt::SpaceGrid >   &p_gridPrevious, const  std::shared_ptr< StOpt::OptimizerDPBase>   &p_optimizer):
         StOpt::TransitionStepRegressionDP(std::dynamic_pointer_cast<StOpt::FullGrid>(p_gridCurrent),
                                           std::dynamic_pointer_cast<StOpt::FullGrid>(p_gridPrevious),
-                                          p_optimizer) {  }
+                                          p_optimizer
+#ifdef USE_MPI
+                                          , boost::mpi::communicator()
+#endif
+                                         ) {  }
 
     py::list  oneStepWrap(const std::vector< Eigen::ArrayXXd >  &p_phiIn,
                           const std::shared_ptr< StOpt::BaseRegression>     &p_condExp) const
@@ -506,7 +526,11 @@ public :
     PySimulateStepRegression(BinaryFileArchiveStOpt &p_ar,  const int &p_iStep,  const std::string &p_nameCont,
                              const   std::shared_ptr< StOpt::SpaceGrid > &p_pGridFollowing,
                              const  std::shared_ptr< StOpt::OptimizerDPBase > &p_pOptimize):
-        StOpt::SimulateStepRegression(p_ar, p_iStep, p_nameCont, p_pGridFollowing, p_pOptimize)
+        StOpt::SimulateStepRegression(p_ar, p_iStep, p_nameCont, p_pGridFollowing, p_pOptimize
+#ifdef USE_MPI
+                                      , boost::mpi::communicator()
+#endif
+                                     )
     {}
 
     py::list  oneStepWrap(const py::list    &p_statevector,  const Eigen::ArrayXXd   &p_phiInOut) const
@@ -528,7 +552,11 @@ class PySimulateStepRegressionControl : StOpt::SimulateStepRegressionControl
 public :
     PySimulateStepRegressionControl(BinaryFileArchiveStOpt &p_ar,  const int &p_iStep,  const std::string &p_nameCont,
                                     const   std::shared_ptr< StOpt::SpaceGrid > &p_pGridFollowing, const  std::shared_ptr< StOpt::OptimizerBaseInterp > &p_pOptimize):
-        StOpt::SimulateStepRegressionControl(p_ar, p_iStep, p_nameCont, p_pGridFollowing, p_pOptimize)
+        StOpt::SimulateStepRegressionControl(p_ar, p_iStep, p_nameCont, p_pGridFollowing, p_pOptimize
+#ifdef USE_MPI
+                                             , boost::mpi::communicator()
+#endif
+                                            )
     {}
 
     py::list  oneStepWrap(const py::list    &p_statevector,  const Eigen::ArrayXXd   &p_phiInOut) const
@@ -551,7 +579,11 @@ public :
     PyTransitionStepRegressionSwitch(const  std::vector< std::shared_ptr<  StOpt::RegularSpaceIntGrid> >  &p_gridCurrent,
                                      const  std::vector< std::shared_ptr<StOpt::RegularSpaceIntGrid> >  &p_gridPrevious,
                                      const  std::shared_ptr<StOpt::OptimizerSwitchBase > &p_optimizer):
-        StOpt::TransitionStepRegressionSwitch(p_gridCurrent, p_gridPrevious, p_optimizer) {  }
+        StOpt::TransitionStepRegressionSwitch(p_gridCurrent, p_gridPrevious, p_optimizer
+#ifdef USE_MPI
+                                              , boost::mpi::communicator()
+#endif
+                                             ) {  }
 
 
     py::list  oneStepWrap(const std::vector< Eigen::ArrayXXd >  &p_phiIn,
@@ -587,7 +619,11 @@ public :
     PySimulateStepSwitch(BinaryFileArchiveStOpt &p_ar,  const int &p_iStep,  const std::string &p_nameCont,
                          const   std::vector<std::shared_ptr< StOpt::RegularSpaceIntGrid > > &p_pGridFollowing,
                          const   std::shared_ptr< StOpt::OptimizerSwitchBase > &p_pOptimize):
-        StOpt::SimulateStepSwitch(p_ar, p_iStep, p_nameCont, p_pGridFollowing, p_pOptimize)
+        StOpt::SimulateStepSwitch(p_ar, p_iStep, p_nameCont, p_pGridFollowing, p_pOptimize
+#ifdef USE_MPI
+                                  , boost::mpi::communicator()
+#endif
+                                 )
     {}
 
     py::list  oneStepWrap(const py::list    &p_statevector,  const Eigen::ArrayXXd   &p_phiInOut) const
@@ -611,7 +647,7 @@ public:
 
     PyFinalStepDPDist(const  std::shared_ptr<StOpt::SpaceGrid> &p_pGridCurrent, const int &p_nbRegime,
                       const Eigen::Array< bool, Eigen::Dynamic, 1>   &p_bdimToSplit):
-        StOpt::FinalStepDPDist(std::dynamic_pointer_cast<StOpt::FullGrid>(p_pGridCurrent), p_nbRegime, p_bdimToSplit) {}
+        StOpt::FinalStepDPDist(std::dynamic_pointer_cast<StOpt::FullGrid>(p_pGridCurrent), p_nbRegime, p_bdimToSplit, boost::mpi::communicator()) {}
 
     std::vector< Eigen::ArrayXXd >   operator()(py::object &p_funcValue, const Eigen::ArrayXXd &p_particles) const
     {
@@ -641,7 +677,7 @@ public:
 
     PyFinalStepZeroDist(const  std::vector< std::shared_ptr< StOpt::RegularSpaceIntGrid> >   &p_pGridCurrent,
                         const  std::vector< Eigen::Array< bool, Eigen::Dynamic, 1> > &p_bdimToSplit):
-        StOpt::FinalStepZeroDist<StOpt::RegularSpaceIntGrid>(p_pGridCurrent, p_bdimToSplit) {}
+        StOpt::FinalStepZeroDist<StOpt::RegularSpaceIntGrid>(p_pGridCurrent, p_bdimToSplit, boost::mpi::communicator()) {}
 
     std::vector< Eigen::ArrayXXd >   operator()(const int   &p_nbSimul) const
     {
@@ -660,7 +696,7 @@ public :
     PyTransitionStepRegressionDPDist(const std::shared_ptr< StOpt::SpaceGrid >   &p_gridCurrent,  const std::shared_ptr< StOpt::SpaceGrid >   &p_gridPrevious, const  std::shared_ptr< StOpt::OptimizerDPBase>   &p_optimizer):
         StOpt::TransitionStepRegressionDPDist(std::dynamic_pointer_cast<StOpt::FullGrid>(p_gridCurrent),
                                               std::dynamic_pointer_cast<StOpt::FullGrid>(p_gridPrevious),
-                                              p_optimizer) {  }
+                                              p_optimizer, boost::mpi::communicator()) {  }
 
     py::list  oneStepWrap(const std::vector< Eigen::ArrayXXd >  &p_phiIn,
                           const std::shared_ptr< StOpt::BaseRegression>     &p_condExp) const
@@ -708,7 +744,7 @@ public :
                                  const   std::shared_ptr< StOpt::SpaceGrid > &p_pGridFollowing,
                                  const  std::shared_ptr< StOpt::OptimizerDPBase > &p_pOptimize,
                                  const bool &p_bOneFile):
-        StOpt::SimulateStepRegressionDist(p_ar, p_iStep, p_nameCont, std::dynamic_pointer_cast<StOpt::FullGrid>(p_pGridFollowing), p_pOptimize, p_bOneFile)
+        StOpt::SimulateStepRegressionDist(p_ar, p_iStep, p_nameCont, std::dynamic_pointer_cast<StOpt::FullGrid>(p_pGridFollowing), p_pOptimize, p_bOneFile, boost::mpi::communicator())
     {}
 
     py::list  oneStepWrap(const py::list    &p_statevector,  const Eigen::ArrayXXd   &p_phiInOut) const
@@ -735,7 +771,7 @@ public :
                                         const  std::shared_ptr< StOpt::OptimizerDPBase > &p_pOptimize,
                                         const bool &p_bOneFile):
         StOpt::SimulateStepRegressionControlDist(p_ar, p_iStep, p_nameCont, std::dynamic_pointer_cast<StOpt::FullGrid>(p_pGridCurrent),
-                std::dynamic_pointer_cast<StOpt::FullGrid>(p_pGridFollowing), p_pOptimize, p_bOneFile)
+                std::dynamic_pointer_cast<StOpt::FullGrid>(p_pGridFollowing), p_pOptimize, p_bOneFile, boost::mpi::communicator())
     {}
 
     py::list  oneStepWrap(const py::list    &p_statevector,  const Eigen::ArrayXXd   &p_phiInOut) const
@@ -756,7 +792,7 @@ public :
     PyTransitionStepTreeDPDist(const std::shared_ptr< StOpt::SpaceGrid >   &p_gridCurrent,  const std::shared_ptr< StOpt::SpaceGrid >   &p_gridPrevious, const  std::shared_ptr< StOpt::OptimizerDPTreeBase>   &p_optimizer):
         StOpt::TransitionStepTreeDPDist(std::dynamic_pointer_cast<StOpt::FullGrid>(p_gridCurrent),
                                         std::dynamic_pointer_cast<StOpt::FullGrid>(p_gridPrevious),
-                                        p_optimizer) {  }
+                                        p_optimizer, boost::mpi::communicator()) {  }
 
     py::list  oneStepWrap(const std::vector< Eigen::ArrayXXd >  &p_phiIn,
                           const std::shared_ptr< StOpt::Tree>     &p_condExp) const
@@ -798,7 +834,7 @@ public :
                            const   std::shared_ptr< StOpt::SpaceGrid > &p_pGridFollowing,
                            const  std::shared_ptr< StOpt::OptimizerDPTreeBase > &p_pOptimize,
                            const bool &p_bOneFile):
-        StOpt::SimulateStepTreeDist(p_ar, p_iStep, p_nameCont, std::dynamic_pointer_cast<StOpt::FullGrid>(p_pGridFollowing), p_pOptimize, p_bOneFile)
+        StOpt::SimulateStepTreeDist(p_ar, p_iStep, p_nameCont, std::dynamic_pointer_cast<StOpt::FullGrid>(p_pGridFollowing), p_pOptimize, p_bOneFile, boost::mpi::communicator())
     {}
 
     py::list  oneStepWrap(const py::list    &p_statevector,  const Eigen::ArrayXXd   &p_phiInOut) const
@@ -825,7 +861,7 @@ public :
                                   const  std::shared_ptr< StOpt::OptimizerDPTreeBase > &p_pOptimize,
                                   const bool &p_bOneFile):
         StOpt::SimulateStepTreeControlDist(p_ar, p_iStep, p_nameCont, std::dynamic_pointer_cast<StOpt::FullGrid>(p_pGridCurrent),
-                                           std::dynamic_pointer_cast<StOpt::FullGrid>(p_pGridFollowing), p_pOptimize, p_bOneFile)
+                                           std::dynamic_pointer_cast<StOpt::FullGrid>(p_pGridFollowing), p_pOptimize, p_bOneFile, boost::mpi::communicator())
     {}
 
     py::list  oneStepWrap(const py::list    &p_statevector,  const Eigen::ArrayXXd   &p_phiInOut) const
@@ -848,7 +884,7 @@ public :
     PyTransitionStepRegressionSwitchDist(const  std::vector< std::shared_ptr<  StOpt::RegularSpaceIntGrid> >  &p_gridCurrent,
                                          const  std::vector< std::shared_ptr<StOpt::RegularSpaceIntGrid> >  &p_gridPrevious,
                                          const  std::shared_ptr<StOpt::OptimizerSwitchBase > &p_optimizer):
-        StOpt::TransitionStepRegressionSwitchDist(p_gridCurrent, p_gridPrevious, p_optimizer) {  }
+        StOpt::TransitionStepRegressionSwitchDist(p_gridCurrent, p_gridPrevious, p_optimizer, boost::mpi::communicator()) {  }
 
 
     py::list  oneStepWrap(const std::vector< Eigen::ArrayXXd >  &p_phiIn,
@@ -880,14 +916,14 @@ public :
 Eigen::ArrayXd  pyReconstructProc0Mpi(const Eigen::ArrayXd &p_point, const std::shared_ptr< StOpt::SpaceGrid> &p_grid, const Eigen::ArrayXXd    &p_values, const Eigen::Array< bool, Eigen::Dynamic, 1>   &p_bdimToSplit)
 {
     std::shared_ptr< Eigen::ArrayXXd > values = std::make_shared<Eigen::ArrayXXd > (p_values);
-    return reconstructProc0Mpi(p_point, std::dynamic_pointer_cast<StOpt::FullGrid>(p_grid), values, p_bdimToSplit);
+    return reconstructProc0Mpi(p_point, std::dynamic_pointer_cast<StOpt::FullGrid>(p_grid), values, p_bdimToSplit, boost::mpi::communicator());
 }
 
 
 Eigen::ArrayXd  pyReconstructProc0ForIntMpi(const Eigen::ArrayXi &p_point, const std::shared_ptr< StOpt::RegularSpaceIntGrid> &p_grid, const Eigen::ArrayXXd    &p_values, const Eigen::Array< bool, Eigen::Dynamic, 1>   &p_bdimToSplit)
 {
     std::shared_ptr< Eigen::ArrayXXd > values = std::make_shared<Eigen::ArrayXXd > (p_values);
-    return reconstructProc0ForIntMpi(p_point, p_grid, values, p_bdimToSplit);
+    return reconstructProc0ForIntMpi(p_point, p_grid, values, p_bdimToSplit, boost::mpi::communicator());
 }
 
 #endif
