@@ -63,7 +63,10 @@ BOOST_AUTO_TEST_CASE(testMMMModelInOptimizationSimulation)
     double eta =  0.0541753484637; //
     double T = 1.; // number of years
     size_t nbStep = T * 12; // number of optimization date (equal time step)
-    std::string nameArch = "Store";
+    std::string nameArch = "StoreMPI";
+#ifdef USE_MPI
+    nameArch += to_string(world.size());
+#endif
     // forward
     bool bForward = false;
     std::shared_ptr< MMMSimulator>  sim = std::make_shared<MMMSimulator>(initialValue, alpha0, eta, T, nbStep, nbSimul, bForward, nameArch
@@ -99,7 +102,10 @@ BOOST_AUTO_TEST_CASE(testMMMModelInOptimizationSimulation)
     shared_ptr<RegularLegendreGrid> grid = make_shared<RegularLegendreGrid>(lowValues, stepGrid, nbStepGrid, p_poly);
     // initial portfolio value
     ArrayXd initialPortfolio = ArrayXd::Constant(1, initialValue);
-    std::string fileToDump = "CondExp";
+    std::string fileToDump = "CondExpMMM";
+#ifdef USE_MPI
+    fileToDump+= to_string(world.size());
+#endif
     // discretization of portfolio composition  (0,1)
     // with 1  at each time invest all in risky asset or bond
     int nbStepPort = 1;
@@ -181,14 +187,10 @@ void testDistribution(const bool &p_bOneFile)
     double eta =  0.0541753484637; //
     double T = 1.; // number of years
     size_t nbStep = T * 12; // number of optimization date (equal time step)
-    std::string nameArch = "Store";
+    std::string nameArch = "StoreMMMDI" +   to_string(world.size()) ;
     // forward
     bool bForward = false;
-    std::shared_ptr< MMMSimulator>  sim = std::make_shared<MMMSimulator>(initialValue, alpha0, eta, T, nbStep, nbSimul, bForward, nameArch
-#ifdef USE_MPI
-                                          , world
-#endif
-                                                                        );
+    std::shared_ptr< MMMSimulator>  sim = std::make_shared<MMMSimulator>(initialValue, alpha0, eta, T, nbStep, nbSimul, bForward, nameArch , world );
 
     // Determine max of the diffusion cone
     double maxCone = 0. ;
@@ -213,7 +215,7 @@ void testDistribution(const bool &p_bOneFile)
     shared_ptr<RegularLegendreGrid> grid = make_shared<RegularLegendreGrid>(lowValues, stepGrid, nbStepGrid, p_poly);
     // initial portfolio value
     ArrayXd initialPortfolio = ArrayXd::Constant(1, initialValue);
-    std::string fileToDump = "CondExp";
+    std::string fileToDump = "CondExp"+   to_string(world.size());
     // discretization of portfolio composition  (0,1)
     // with 1  at each time invest all in risky asset or bond
     int nbStepPort = 1;
