@@ -6,6 +6,7 @@
 #endif
 #define BOOST_TEST_DYN_LINK
 #include <functional>
+#include <stdint.h>
 #ifdef USE_MPI
 #include <boost/mpi.hpp>
 #endif
@@ -280,12 +281,18 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimization)
     int initialRegime = 0;
     string fileToDumpDistr = "CondExpDistr";
 #ifdef USE_MPI
+    fileToDumpDistr = fileToDumpDistr + to_string(world.size());
+   
     bool bOneFile = false;
     // regressor
     shared_ptr<BaseRegression > regressor(new LocalLinearRegression(nbMesh));
     // link the simulations to the optimizer
     optimizer->setSimulator(simulator);
-    double valueParal = DynamicProgrammingByRegressionDist(grid, optimizer, regressor, vFunction, initialStock, initialRegime, fileToDumpDistr, bOneFile);
+    double valueParal = DynamicProgrammingByRegressionDist(grid, optimizer, regressor, vFunction, initialStock, initialRegime, fileToDumpDistr, bOneFile
+#ifdef USE_MPI
+                        , world
+#endif
+                                                          );
     if (world.rank() == 0)
     {
         BOOST_CHECK_EQUAL(valueSeq, valueParal);
@@ -299,14 +306,19 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimization)
     // link the simulations to the optimizer
     optimizer->setSimulator(simulator1);
     // using continuation values
-    double value =  DynamicProgrammingByRegression(grid, optimizer, regressor1, vFunction, initialStock, initialRegime, fileToDump);
+    double value =  DynamicProgrammingByRegression(grid, optimizer, regressor1, vFunction, initialStock, initialRegime, fileToDump
+#ifdef USE_MPI
+                    , world
+#endif
+                                                  );
 #ifdef USE_MPI
     if (world.rank() == 0)
 #endif
         BOOST_CHECK_EQUAL(valueSeq, value);
 #endif
 }
-
+// only if 64 bits
+#if UINTPTR_MAX == 0xffffffffffffffff
 BOOST_AUTO_TEST_CASE(testSwingOptionInOptimizationKernel)
 {
 #ifdef USE_MPI
@@ -379,12 +391,13 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimizationKernel)
     int initialRegime = 0;
     string fileToDumpDistr = "CondExpDistr";
 #ifdef USE_MPI
+    fileToDumpDistr = fileToDumpDistr + to_string(world.size());
     bool bOneFile = false;
     // regressor
     shared_ptr<BaseRegression > regressor = make_shared<LocalGridKernelRegression>(bandWidth, 1., true);
     // link the simulations to the optimizer
     optimizer->setSimulator(simulator);
-    double valueParal = DynamicProgrammingByRegressionDist(grid, optimizer, regressor, vFunction, initialStock, initialRegime, fileToDumpDistr, bOneFile);
+    double valueParal = DynamicProgrammingByRegressionDist(grid, optimizer, regressor, vFunction, initialStock, initialRegime, fileToDumpDistr, bOneFile, world);
     cout << " By framework" <<  valueParal << " Analytical " << analytical << endl ;
     if (world.rank() == 0)
     {
@@ -406,7 +419,8 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimizationKernel)
         BOOST_CHECK_EQUAL(valueSeq, value);
 #endif
 }
-
+// only if 64 bits 
+#endif
 
 #ifdef USE_MPI
 /// \brief function to test stock in dimension above 1
@@ -457,13 +471,13 @@ void testMultiStock(const int p_ndim)
     // initial values
     ArrayXd initialStock = ArrayXd::Constant(p_ndim, 0.);
     int initialRegime = 0;
-    string fileToDump = "CondExp";
+    string fileToDump = "CondExpForMPI" + to_string(world.size());
     // regressor
     shared_ptr< BaseRegression > regressor(new LocalLinearRegression(nbMesh));
     bool bOneFile = false;
     // link the simulations to the optimizer
     optimizer->setSimulator(simulator);
-    double  valueParal = DynamicProgrammingByRegressionDist(grid, optimizer, regressor, vFunction, initialStock, initialRegime, fileToDump, bOneFile);
+    double  valueParal = DynamicProgrammingByRegressionDist(grid, optimizer, regressor, vFunction, initialStock, initialRegime, fileToDump, bOneFile, world);
     if (world.rank() == 0)
     {
         BOOST_CHECK_CLOSE(valueSeq * p_ndim, valueParal, accuracyNearlyEqual);
